@@ -3,7 +3,7 @@ __all__ = ["AMFError", "RTMPError", "RTMPTimeoutError"]
 class AMFError(Exception):
     pass
 
-class RTMPError(Exception):
+class RTMPError(IOError):
     pass
 
 class RTMPTimeoutError(RTMPError):
